@@ -397,20 +397,28 @@ namespace FCam {
             case TIFF_RATIONAL: {
                 if (v.type == TagValue::Double) {
                     double vd = v;
+                    if (entry.type == TIFF_RATIONAL && vd < 0 ) {
+                        vd = 0;
+                        warning(Event::FileSaveWarning, "IfdEntry: Entry value less than zero when writing a RATIONAL entry. Clamped to zero.");
+                    }
                     // \todo Fix Rationals
-                    uint32_t num = vd * (2 << 20);
-                    uint32_t den = 2 << 20;;
-                    written = fwrite(&num, sizeof(uint32_t), 1, fw);
-                    written += fwrite(&den, sizeof(uint32_t), 1, fw);
+                    int32_t num = vd * (1 << 20);
+                    int32_t den = 1 << 20;
+                    written = fwrite(&num, sizeof(int32_t), 1, fw);
+                    written += fwrite(&den, sizeof(int32_t), 1, fw);
                     written /= 2;
                 } else {
                     std::vector<double> &vd = v;
                     written = 0;
                     for (size_t i=0; i < vd.size(); i++) {
-                        uint32_t num = vd[i] * (2 << 20);
-                        uint32_t den = 2 << 20;
-                        written += fwrite(&num, sizeof(uint32_t), 1, fw);
-                        written += fwrite(&den, sizeof(uint32_t), 1, fw);
+                        if (entry.type == TIFF_RATIONAL && vd[i] < 0 ) {
+                            vd[i] = 0;
+                            warning(Event::FileSaveWarning, "IfdEntry: Entry value less than zero when writing a RATIONAL entry. Clamped to zero.");
+                        }
+                        int32_t num = vd[i] * (1 << 20);
+                        int32_t den = 1 << 20;
+                        written += fwrite(&num, sizeof(int32_t), 1, fw);
+                        written += fwrite(&den, sizeof(int32_t), 1, fw);
                     }
                     written /= 2;
                 }
